import * as _nuxt_schema from '@nuxt/schema';
import { CookieOptions } from 'nuxt/app';
import { SupabaseClientOptions } from '@supabase/supabase-js';

declare module '@nuxt/schema' {
    interface PublicRuntimeConfig {
        supabase: {
            url: string;
            key: string;
            redirect: boolean;
            redirectOptions: RedirectOptions;
            cookieName: string;
            cookieOptions: CookieOptions;
            types: string | false;
            clientOptions: SupabaseClientOptions<string>;
        };
    }
}
interface RedirectOptions {
    login: string;
    callback: string;
    include?: string[];
    exclude?: string[];
    cookieRedirect?: boolean;
}

interface ModuleOptions {
    /**
     * Supabase API URL
     * @default process.env.SUPABASE_URL
     * @example 'https://*.supabase.co'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    url: string;
    /**
     * Supabase Client API Key
     * @default process.env.SUPABASE_KEY
     * @example '123456789'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    key: string;
    /**
     * Supabase Service key
     * @default process.env.SUPABASE_SERVICE_KEY
     * @example '123456789'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    serviceKey: string;
    /**
     * Redirect automatically to login page if user is not authenticated
     * @default `true`
     * @type boolean
     */
    redirect?: boolean;
    /**
     * Redirection options, set routes for login and callback redirect
     * @default
     * {
        login: '/login',
        callback: '/confirm',
        exclude: [],
      }
     * @type RedirectOptions
     */
    redirectOptions?: RedirectOptions;
    /**
     * Cookie name used for storing the redirect path when using the `redirect` option, added in front of `-redirect-path` to form the full cookie name e.g. `sb-redirect-path`
     * @default 'sb'
     * @type string
     */
    cookieName?: string;
    /**
     * Cookie options
     * @default {
        maxAge: 60 * 60 * 8,
        sameSite: 'lax',
        secure: true,
      }
     * @type CookieOptions
     * @docs https://nuxt.com/docs/api/composables/use-cookie#options
     */
    cookieOptions?: CookieOptions;
    /**
     * Path to Supabase database type definitions file
     * @default '~/types/database.types.ts'
     * @type string
     */
    types?: string | false;
    /**
     * Supabase client options (overrides default options from `@supabase/ssr`)
     * @default { }
     * @type object
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    clientOptions?: SupabaseClientOptions<string>;
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { type ModuleOptions, type RedirectOptions, _default as default };
